mathtools.is_positive_integer_power_of_two
==========================================

.. autofunction:: abjad.tools.mathtools.is_positive_integer_power_of_two.is_positive_integer_power_of_two
   :noindex:
